
<h1 align="center">
  Pilot Light
</h1>

<p align="center">A lightweight game engine with minimal dependencies.</p>

<h1></h1>

<p align="center">
   <a href="https://github.com/PilotLightTech/pilotlight/actions?workflow=Build"><img src="https://github.com/PilotLightTech/pilotlight/actions/workflows/build.yml/badge.svg?branch=master" alt="build"></a>
   <a href="https://github.com/PilotLightTech/pilotlight/actions?workflow=Static%20Analysis"><img src="https://github.com/PilotLightTech/pilotlight/actions/workflows/static-analysis.yml/badge.svg?branch=master" alt="static-analysis"></a>
   <a href="https://github.com/PilotLightTech/pilotlight/actions?workflow=Tests"><img src="https://github.com/PilotLightTech/pilotlight/actions/workflows/tests.yml/badge.svg?branch=master" alt="tests"></a>
</p>

<p align="center">
  <a href="#information">Information</a> •
  <a href="#developer-notes">Developer Notes</a> • 
  <a href="#license">License</a> •
  <a href="#gallery">Gallery</a> •
  <a href="#inspiration">Inspiration</a>
</p>

<p align="center">
  <a href="https://github.com/PilotLightTech/pilotlight-assets"><img src="https://github.com/PilotLightTech/pilotlight-assets/blob/master/images/tooling2.png" alt="Tooling Image"></a>
</p>

## Information
Under construction.

## Developer Notes
Information for developers can be found in the [wiki](https://github.com/PilotLightTech/pilotlight/wiki). This includes:
* [building](https://github.com/PilotLightTech/pilotlight/wiki/Building)
* [contributing](https://github.com/PilotLightTech/pilotlight/wiki/Contributing)
* [style guide](https://github.com/PilotLightTech/pilotlight/wiki/Style-Guide)

## License
Pilot Light is licensed under the [MIT License](https://github.com/PilotLightTech/pilotlight/blob/master/LICENSE).

## Gallery

<p align="center">
  <a href="https://github.com/PilotLightTech/pilotlight"><img src="https://github.com/PilotLightTech/pilotlight-assets/blob/master/gifs/sponza0.gif" alt="Sponza 0" width="2553"></a>
</p>

## Inspiration
This project is inspired by:
* [Omar Cornut](http://www.miracleworld.net/) & [Dear ImGui](https://github.com/ocornut/imgui).
* Casey Muratori & [Handmade Hero](https://handmadehero.org/)
* Turánszki János & [Wicked Engine](https://wickedengine.net/)
* [Sean Barrett](https://nothings.org/) & his [stb](https://github.com/nothings/stb) libraries
* _The Machinery_ before they were abducted
